SystemOrganization addCategory: #ConfigurationOfCodeSight!

Object subclass: #ConfigurationOfCodeSight
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfCodeSight'!

!ConfigurationOfCodeSight class methodsFor: 'private' stamp: 'bs 10/6/2010 13:57:33.986'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfCodeSight class methodsFor: 'private' stamp: 'bs 10/6/2010 13:57:34.003'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfCodeSight class methodsFor: 'metacello tool support' stamp: 'bs 10/6/2010 13:57:34.022'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfCodeSight class methodsFor: 'metacello tool support' stamp: 'bs 10/6/2010 13:57:34.037'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfCodeSight class methodsFor: 'loading' stamp: 'bs 10/6/2010 13:57:34.068'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfCodeSight class methodsFor: 'metacello tool support' stamp: 'bs 10/6/2010 13:57:34.053'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfCodeSight class methodsFor: 'accessing' stamp: 'bs 10/6/2010 13:57:34.083'!
project

	^self new project! !

!ConfigurationOfCodeSight class methodsFor: 'unloading Metacello' stamp: 'bs 10/6/2010 13:57:34.097'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfCodeSight methodsFor: 'baselines' stamp: 'mt 10/6/2010 14:42:13.257'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/CodeSight'. 
		
		spec project: 'OSProcess' with: [
			spec
				className: 'ConfigurationOfOSProcess';
				repository: 'http://www.squeaksource.com/MetacelloRepository';
				versionString: '4.3.12'].

		spec project: 'SwaUtil' with: [
			spec
				className: 'ConfigurationOfSwaUtil';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
		
		spec
			package: 'MethodWrappers' with: [spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'];
			package: 'Actors' with: [spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].
		
		spec 
            	package: 'Sight-Cst' with: [ 
				spec requires: #('OSProcess' 'MethodWrappers' 'Actors' 'SwaUtil') ];
			package: 'SightL' with: [ spec requires: #('Sight-Cst') ];
			package: 'Sight-Path' with: [ spec requires: #('SightL') ].
		spec
			group: 'default' with: #('Sight-Cst' 'SightL' 'Sight-Path'). ].! !

!ConfigurationOfCodeSight methodsFor: 'baselines' stamp: 'mt 4/27/2011 14:10:43.111'!
baseline101: spec 
	<version: '1.0.1-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/CodeSight'. 
		
		spec project: 'OmniBrowser' with: [
			spec
				className: 'ConfigurationOfOmniBrowser';
				repository: 'http://www.squeaksource.com/MetacelloRepository';
				versionString: '1.2';
				loads: #( Dev )].
			
		spec project: 'OSProcess' with: [
			spec
				className: 'ConfigurationOfOSProcess';
				repository: 'http://www.squeaksource.com/MetacelloRepository';
				versionString: '4.3.12'].
			
		spec project: 'SwaUtil' with: [
			spec
				className: 'ConfigurationOfSwaUtil';
				versionString: 'head';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec
			package: 'MethodWrappers' with: [spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'];
			
			package: 'SWAOBExtensions' with: [spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities';
				requires: #( 'OmniBrowser' )];
			
			package: 'Actors' with: [spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities' ].
		
		spec 
			package: 'Sight-Cst' with: [ 
				spec requires: #( 'OSProcess' 'MethodWrappers' 'Actors' 'SwaUtil') ];
			package: 'SightL' with: [ 
				spec requires: #( 'MethodWrappers' 'Actors' 'SwaUtil' 'Sight-Cst') ];
			package: 'Sight-Path' with: [ spec requires: 'Sight-Cst'; requires: 'SightL' ];
			package: 'Sight-OB' with: [ spec requires: 'Sight-Cst'; requires: 'SightL'; requires: 'SWAOBExtensions'].
		
		spec
			group: 'default' with: #('Core');
			group: 'cst' with: #('Sight-Cst');
			group: 'Core' with: #('Sight-Cst' 'SightL' 'Sight-Path');
			group: 'Core + OB' with: #('Core' 'Sight-OB'). ].! !

!ConfigurationOfCodeSight methodsFor: 'symbolic versions' stamp: 'mt 4/27/2011 14:01:41.692'!
development: spec
	<symbolicVersion: #development>
	
	spec for: #'squeak4.2.x' version: '1.0.1'.! !

!ConfigurationOfCodeSight methodsFor: 'accessing' stamp: 'bs 10/6/2010 13:57:33.97'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfCodeSight methodsFor: 'versions' stamp: 'bs 10/6/2010 14:07:36.331'!
version100: spec 
        <version: '1.0' imports: #('1.0-baseline') >
        
       spec for: #common do: [
                spec blessing: #release.
       "         spec 
                        package: 'Sight-Cst' with: 'Example-Core-DaleHenrichs.1';
                        package: 'SightL' with: 'Example-Tests-DaleHenrichs.1';
				package: 'Sight-Path' with: 'Example-Tests-DaleHenrichs.1';"].! !

!ConfigurationOfCodeSight methodsFor: 'versions' stamp: 'mt 4/27/2011 14:02:14.865'!
version101: spec 
	<version: '1.0.1' imports: #('1.0.1-baseline') >
        
	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Bastian Steinert'].! !
